crafft_screening_tool: CRAFFT Questionnaire for Adolescent Substance Abuse

View source: R/neelpackage.R

crafft_screening_toolR Documentation

CRAFFT Questionnaire for Adolescent Substance Abuse

Description

Calculates the CRAFFT screening score to identify substance use problems in adolescents (age 12-21). The tool consists of three opening questions regarding use of alcohol, marijuana, or other drugs in the past 12 months. If any are positive, six further questions (Car, Relax, Alone, Forget, Friends, Trouble) are asked. If the opening questions are negative, only the 'Car' question is asked.

Usage

crafft_screening_tool(drink_alcohol, smoke_marijuana, use_other_drugs,
                      car_driven_by_high, relax_use, alone_use, forget_things,
                      friends_family_advice, trouble_while_using)

Arguments

drink_alcohol

Numeric (0 or 1). During the past 12 months, did you drink any alcohol (more than a few sips)? (1 = Yes).

smoke_marijuana

Numeric (0 or 1). During the past 12 months, did you smoke any marijuana or hashish? (1 = Yes).

use_other_drugs

Numeric (0 or 1). During the past 12 months, did you use anything else to get high? (1 = Yes).

car_driven_by_high

Numeric (0 or 1). Have you ever ridden in a CAR driven by someone (including yourself) who was "high" or had been using alcohol or drugs? (1 = Yes).

relax_use

Numeric (0 or 1). Do you ever use alcohol or drugs to RELAX, feel better about yourself, or fit in? (1 = Yes).

alone_use

Numeric (0 or 1). Do you ever use alcohol or drugs while you are by yourself, or ALONE? (1 = Yes).

forget_things

Numeric (0 or 1). Do you ever FORGET things you did while using alcohol or drugs? (1 = Yes).

friends_family_advice

Numeric (0 or 1). Do your family or FRIENDS ever tell you that you should cut down on your drinking or drug use? (1 = Yes).

trouble_while_using

Numeric (0 or 1). Have you ever gotten into TROUBLE while you were using alcohol or drugs? (1 = Yes).

Value

A list containing:

CRAFFT_Score

The calculated total score (Range 0-6).

Screening_Result

Interpretation of the score (Positive >= 2).

Recommendation

Clinical guidance based on the result.

References

Knight JR, Shrier LA, Bravender TD, et al. A new brief screen for adolescent substance abuse. Arch Pediatr Adolesc Med. 1999;153(6):591-596. doi:10.1001/archpedi.153.6.591

Examples


# Example 1: Positive Screen
# Alcohol use (1), Car (1), Friends (1) -> Score 2
crafft_screening_tool(1, 0, 0, 1, 0, 0, 0, 1, 0)

# Example 2: Negative Screen (No substance use in past year)
# No alcohol/drugs, Car question asked (0) -> Score 0
crafft_screening_tool(0, 0, 0, 0, 0, 0, 0, 0, 0)

cliot documentation built on Dec. 1, 2025, 1:06 a.m.