| free_water_deficit | R Documentation |
Calculates the estimated free water deficit in patients with hypernatremia. The formula relies on Total Body Water (TBW), which is estimated based on the patient's age, sex, and weight. This calculation helps guide fluid replacement therapy to lower serum sodium levels safely.
free_water_deficit(current_na, weight_kg, age, sex, target_na = 140)
current_na |
Numeric. Current serum sodium level in mEq/L. |
weight_kg |
Numeric. Patient weight in kilograms. |
age |
Numeric. Patient age in years. Used to determine the TBW fraction (Children: 0.6; Adults 18-64: M=0.6/F=0.5; Elderly >=65: M=0.5/F=0.45). |
sex |
String. Patient sex ("Male" or "Female"). |
target_na |
Numeric. The desired target serum sodium level. Defaults to 140 mEq/L. |
A list containing:
Free_Water_Deficit_L |
The estimated volume of free water required to correct the sodium to the target level. |
Total_Body_Water_L |
The estimated Total Body Water used in the calculation. |
TBW_Fraction_Used |
The coefficient used to calculate TBW based on demographics. |
Adrogué HJ, Madias NE. Hypernatremia. N Engl J Med. 2000;342(20):1493-1499. doi:10.1056/NEJM200005183422006
# Example 1: Adult Male
# Na 160, Wt 75kg, Age 40 (TBW factor 0.6)
# TBW = 45L. Deficit = 45 * ((160/140) - 1) = 6.4 L
free_water_deficit(160, 75, 40, "male")
# Example 2: Elderly Female
# Na 155, Wt 60kg, Age 75 (TBW factor 0.45)
# TBW = 27L. Deficit = 27 * ((155/140) - 1) = 2.9 L
free_water_deficit(155, 60, 75, "female")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.