immunization_schedule_cdc: CDC Childhood Immunization Schedule

View source: R/neelpackage.R

immunization_schedule_cdcR Documentation

CDC Childhood Immunization Schedule

Description

Generates a list of recommended vaccines based on the child's current age in months, following the standard CDC immunization schedule (birth through 18 years). This function assumes the child is on track with previous doses.

Usage

immunization_schedule_cdc(current_age_months)

Arguments

current_age_months

Numeric. The age of the patient in months.

Value

A list containing:

Age_Months

Input age.

Recommended_Vaccines

A vector of strings listing the vaccines typically administered at this specific age visit.

References

Centers for Disease Control and Prevention (CDC). Recommended Child and Adolescent Immunization Schedule for ages 18 years or younger, United States, 2024.

Examples


# Example 1: 2 Month Visit
immunization_schedule_cdc(2)

# Example 2: 1 Year Visit (12 months)
immunization_schedule_cdc(12)

# Example 3: 11 Year Visit (132 months)
immunization_schedule_cdc(132)

cliot documentation built on Dec. 1, 2025, 1:06 a.m.