karnofsky_performance_status: Karnofsky Performance Status (KPS) Scale

View source: R/neelpackage.R

karnofsky_performance_statusR Documentation

Karnofsky Performance Status (KPS) Scale

Description

Retrieves the definition and functional category for the Karnofsky Performance Status scale. The KPS allows patients to be classified as to their functional impairment. This can be used to compare effectiveness of different therapies and to assess the prognosis in individual patients.

Usage

karnofsky_performance_status(score)

Arguments

score

Numeric. The KPS score. Must be a multiple of 10 between 0 and 100.

Value

A list containing:

KPS_Score

The input score.

Definition

Specific criteria regarding complaints and evidence of disease.

Functional_Category

Broad description of ability to work, live at home, or need for institutional care.

References

Karnofsky DA, Burchenal JH. The Clinical Evaluation of Chemotherapeutic Agents in Cancer. In: MacLeod CM (Ed), Evaluation of Chemotherapeutic Agents. Columbia Univ Press. 1949:191-205.

Examples


# Example 1: Able to work, minor symptoms
karnofsky_performance_status(90)

# Example 2: Needs frequent medical care
karnofsky_performance_status(50)

cliot documentation built on Dec. 1, 2025, 1:06 a.m.