maintenance_fluids_dosing: Maintenance Fluids Calculator (4-2-1 Rule)

View source: R/neelpackage.R

maintenance_fluids_dosingR Documentation

Maintenance Fluids Calculator (4-2-1 Rule)

Description

Calculates the maintenance fluid requirement for pediatric and adult patients using the Holliday-Segar (4-2-1) rule. This method estimates the hourly IV fluid rate required to maintain hydration based on body weight.

Usage

maintenance_fluids_dosing(weight_kg)

Arguments

weight_kg

Numeric. Patient weight in kilograms.

Details

The 4-2-1 Rule calculates the hourly rate as follows:

  • First 10 kg: 4 mL/kg/hr

  • Next 10 kg (11-20 kg): 2 mL/kg/hr

  • Each kg above 20 kg: 1 mL/kg/hr

Value

A list containing:

Hourly_Rate_mL_hr

The calculated maintenance rate in mL per hour.

Daily_Volume_mL_day

The total fluid volume required over 24 hours.

References

Holliday MA, Segar WE. The maintenance need for water in parenteral fluid therapy. Pediatrics. 1957;19(5):823-832.

Examples


# Example 1: Adult (70 kg)
# 40 + 20 + 50 = 110 mL/hr
maintenance_fluids_dosing(70)

# Example 2: Child (15 kg)
# 40 + (5 * 2) = 50 mL/hr
maintenance_fluids_dosing(15)

cliot documentation built on Dec. 1, 2025, 1:06 a.m.