| mskcc_gist_recurrence_risk | R Documentation |
Calculates the likelihood of recurrence-free survival (RFS) at 2 and 5 years after complete surgical resection of a localized primary Gastrointestinal Stromal Tumor (GIST). This nomogram (Goldjsher et al.) uses tumor size, location, and mitotic index.
mskcc_gist_recurrence_risk(tumor_size_cm, tumor_site, mitotic_index_ge_5)
tumor_size_cm |
Numeric. Largest diameter of the tumor in centimeters. |
tumor_site |
String. Location of the tumor. Options: "stomach", "small_intestine", "colon_rectum", "other". |
mitotic_index_ge_5 |
Numeric (0 or 1). Mitotic index >= 5 per 50 High Power Fields (HPF). (1 = Yes). |
A list containing:
Recurrence_Free_Survival_2yr |
Estimated percentage of patients recurrence-free at 2 years. |
Recurrence_Free_Survival_5yr |
Estimated percentage of patients recurrence-free at 5 years. |
Risk_of_Recurrence_2yr |
Estimated percentage risk of recurrence within 2 years. |
Risk_of_Recurrence_5yr |
Estimated percentage risk of recurrence within 5 years. |
Goldjsher D, Joanis V, DeMatteo RP, et al. Development and validation of a prognostic nomogram for recurrence-free survival after complete surgical resection of localized, primary gastrointestinal stromal tumor: a retrospective analysis. Lancet Oncol. 2009;10(11):1045-1052. doi:10.1016/S1470-2045(09)70242-6
# Example 1: Low Risk
# 3cm Stomach GIST, Low Mitosis
mskcc_gist_recurrence_risk(3, "stomach", 0)
# Example 2: High Risk
# 12cm Small Bowel GIST, High Mitosis
mskcc_gist_recurrence_risk(12, "small_intestine", 1)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.