| nexus_head_ct_rule | R Documentation |
Calculates the NEXUS Head CT result to determine the need for head CT imaging in blunt head trauma patients. If any one of the eight criteria is present, the patient is not considered low risk, and imaging is indicated.
nexus_head_ct_rule(age_ge_65, skull_fracture_evidence, scalp_hematoma,
neurologic_deficit, altered_alertness, abnormal_behavior,
coagulopathy, persistent_vomiting)
age_ge_65 |
Numeric (0 or 1). Is the patient 65 years of age or older? (1 = Yes). |
skull_fracture_evidence |
Numeric (0 or 1). Evidence of significant skull fracture? (1 = Yes). |
scalp_hematoma |
Numeric (0 or 1). Scalp hematoma present? (1 = Yes). |
neurologic_deficit |
Numeric (0 or 1). Neurologic deficit present? (1 = Yes). |
altered_alertness |
Numeric (0 or 1). Altered level of alertness? (1 = Yes). |
abnormal_behavior |
Numeric (0 or 1). Abnormal behavior present? (1 = Yes). |
coagulopathy |
Numeric (0 or 1). Coagulopathy present? (1 = Yes). |
persistent_vomiting |
Numeric (0 or 1). Persistent vomiting? (1 = Yes). |
A list containing:
Result |
Recommendation regarding the need for Head CT ("Indicated" or "Not Indicated"). |
Inputs |
A summary of the criteria evaluated. |
Mower WR, Hoffman JR, Herbert M, et al. Developing a decision instrument to guide computed tomographic imaging of blunt head injury patients. J Trauma. 2005;59(4):954-959. doi:10.1097/01.ta.0000187813.79047.42
# Example 1: Low Risk
# No criteria present
nexus_head_ct_rule(0, 0, 0, 0, 0, 0, 0, 0)
# Example 2: Indicated (Age)
# 70yo, no other findings
nexus_head_ct_rule(1, 0, 0, 0, 0, 0, 0, 0)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.