nvps_pain_score: Nonverbal Pain Scale (NVPS) for Nonverbal Patients

View source: R/neelpackage.R

nvps_pain_scoreR Documentation

Nonverbal Pain Scale (NVPS) for Nonverbal Patients

Description

Calculates the NVPS score to assess pain in patients who are unable to verbalize their pain (e.g., sedated, intubated, or cognitively impaired patients). The scale evaluates five categories: Face, Activity, Guarding, Physiology (Vital Signs), and Respiratory.

Usage

nvps_pain_score(face, activity, guarding, physiology_vital_signs, respiratory)

Arguments

face

Numeric (0-2). 0: No particular expression or smile. 1: Occasional grimace, tearing, frowning, wrinkled forehead. 2: Frequent grimace, tearing, frowning, wrinkled forehead.

activity

Numeric (0-2). 0: Lying quietly, normal position. 1: Seeking attention through movement or slow/cautious movement. 2: Restless, excessive activity and/or withdrawal reflexes.

guarding

Numeric (0-2). 0: Lying quietly, no positioning of hands over areas of body. 1: Splinting areas of the body, tense. 2: Rigid, stiff.

physiology_vital_signs

Numeric (0-2). 0: Baseline vital signs unchanged. 1: Change in SBP > 20 mmHg or HR > 20 bpm. 2: Change in SBP > 30 mmHg or HR > 25 bpm.

respiratory

Numeric (0-2). 0: Baseline RR/SpO2/compliance unchanged. 1: RR > 10 above baseline, 5% decrease in SpO2, or mild ventilator dyssynchrony. 2: RR > 20 above baseline, 10% decrease in SpO2, or severe ventilator dyssynchrony.

Value

A list containing:

NVPS_Score

The calculated total score (Range 0-10).

Interpretation

Clinical interpretation of pain severity (No/Mild, Moderate, Severe).

References

Odhner, M., Wegman, D., Freeland, N., Steinmetz, A., & Ingersoll, G. L. (2003). Assessing pain control in nonverbal critically ill adults. Dimensions of Critical Care Nursing, 22(6), 260-267.

Examples


# Example 1: Moderate Pain
# Grimacing(1), Restless(2), Rigid(2), Stable Vitals(0), Mild Dyssynchrony(1)
# Score = 6
nvps_pain_score(1, 2, 2, 0, 1)

# Example 2: No Pain
# All baseline/normal
# Score = 0
nvps_pain_score(0, 0, 0, 0, 0)

cliot documentation built on Dec. 1, 2025, 1:06 a.m.

Related to nvps_pain_score in cliot...