nyha_functional_classification: New York Heart Association (NYHA) Functional Classification

View source: R/neelpackage.R

nyha_functional_classificationR Documentation

New York Heart Association (NYHA) Functional Classification

Description

Retrieves the clinical description for the NYHA Functional Classification. This system provides a simple way of classifying the extent of heart failure based on the severity of symptoms and physical activity limitation.

Usage

nyha_functional_classification(class_grade)

Arguments

class_grade

Numeric (1-4). The assessed NYHA Class. 1: No limitation of physical activity. 2: Slight limitation of physical activity. 3: Marked limitation of physical activity. 4: Unable to carry on any physical activity without discomfort; symptoms at rest.

Value

A list containing:

NYHA_Class

The formatted class string (e.g., "Class I").

Description

The clinical definition associated with the class.

References

The Criteria Committee of the New York Heart Association. Nomenclature and Criteria for Diagnosis of Diseases of the Heart and Great Vessels. 9th ed. Boston, Mass: Little, Brown & Co; 1994:253-256.

Examples


# Example 1: Class II (Slight limitation)
nyha_functional_classification(2)

# Example 2: Class IV (Symptoms at rest)
nyha_functional_classification(4)

cliot documentation built on Dec. 1, 2025, 1:06 a.m.