| osiris_osteoporosis_score | R Documentation |
Calculates the OSIRIS score to stratify the risk of osteoporosis in postmenopausal women. The score utilizes four simple clinical variables: age, body weight, current hormone replacement therapy (HRT) use, and history of prior low-impact fracture. It aids in selecting women for Bone Mineral Density (BMD) testing.
osiris_osteoporosis_score(age, weight_kg, history_fracture, estrogen_therapy)
age |
Numeric. Patient age in years. |
weight_kg |
Numeric. Patient weight in kilograms. |
history_fracture |
Numeric (0 or 1). History of previous low-impact fracture (e.g., wrist, spine, hip) occurring after age 45. (1 = Yes, -2 points). |
estrogen_therapy |
Numeric (0 or 1). Current use of Estrogen Replacement Therapy / Hormone Replacement Therapy (HRT). (1 = Yes, +2 points). |
A list containing:
OSIRIS_Score |
The calculated index score. |
Risk_Category |
Classification (High Risk < 1, Medium Risk 1-3, Low Risk > 3). |
Recommendation |
Guidance regarding BMD testing. |
Sedrani O, et al. Accelerating the diagnosis of osteoporosis. The OSIRIS rule. (Osteoporosis Index of Risk). 2002.
# Example 1: High Risk
# 75yo, 50kg, Prior Fracture (+2 negative points), No HRT
# Base = (50-75)*0.2 = -5. Fx = -2. Total = -7.
osiris_osteoporosis_score(75, 50, 1, 0)
# Example 2: Low Risk
# 55yo, 70kg, No Fracture, On HRT (+2 positive points)
# Base = (70-55)*0.2 = 3. HRT = +2. Total = 5.
osiris_osteoporosis_score(55, 70, 0, 1)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.