| reach_b_score | R Documentation |
Calculates the REACH-B (Risk Estimation for Hepatocellular Carcinoma in Chronic Hepatitis B) score. This tool estimates the risk of developing HCC at 3, 5, and 10 years in patients with chronic hepatitis B without cirrhosis. It incorporates gender, age, ALT levels, HBeAg status, and serum HBV DNA levels.
reach_b_score(sex, age, alt_u_l, hbeag_positive, hbv_dna, dna_units = "IU/mL")
sex |
String. Patient sex ("Male" or "Female"). Male adds 2 points. |
age |
Numeric. Patient age in years. (Points range from 0 for 30-34y to 7 for >=65y). |
alt_u_l |
Numeric. Serum Alanine Aminotransferase (ALT) level in U/L. (<15: 0, 15-44: 1, >=45: 2). |
hbeag_positive |
Numeric (0 or 1). Hepatitis B e-Antigen status. (1 = Positive, +2 points). |
hbv_dna |
Numeric. Serum HBV DNA level. |
dna_units |
String. Units for HBV DNA input. Options: "IU/mL" (default) or "copies/mL". (Conversion: 1 IU/mL approx 5 copies/mL). |
A list containing:
REACH_B_Score |
The calculated risk score (Range 0-17). |
HCC_Risk_3_Year |
Estimated 3-year risk of developing HCC. |
HCC_Risk_5_Year |
Estimated 5-year risk of developing HCC. |
HCC_Risk_10_Year |
Estimated 10-year risk of developing HCC. |
Yang HI, Yuen MF, Chan HL, et al. Risk estimation for hepatocellular carcinoma in chronic hepatitis B (REACH-B): development and validation of a predictive score. Lancet Oncol. 2011;12(6):568-574. doi:10.1016/S1470-2045(11)70077-8
# Example 1: High Risk Male
# 50yo, ALT 50, HBeAg+, DNA 10^6 copies/mL
# Score: Male(2) + Age 50(4) + ALT(2) + HBeAg(2) + DNA(4) = 14
reach_b_score("male", 50, 50, 1, 1000000, "copies/mL")
# Example 2: Low Risk Female
# 35yo, ALT 10, HBeAg-, DNA 2000 IU/mL (10^4 copies)
# Score: Female(0) + Age 35(1) + ALT(0) + HBeAg(0) + DNA(3) = 4
reach_b_score("female", 35, 10, 0, 2000, "IU/mL")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.