| riete_hemorrhage_risk | R Documentation |
Calculates the RIETE Score to predict the risk of major hemorrhage within the first 3 months of anticoagulant treatment for Venous Thromboembolism (VTE). The score helps stratify patients into Low, Intermediate, and High risk categories based on six clinical variables.
riete_hemorrhage_risk(age_gt_75, recent_bleeding, cancer, creatinine_gt_1_2,
hemoglobin_lt_13_or_12, pe_diagnosis)
age_gt_75 |
Numeric (0 or 1). Patient age > 75 years. (1 = Yes, +1 point). |
recent_bleeding |
Numeric (0 or 1). Recent major bleeding (within 30 days prior to VTE diagnosis). (1 = Yes, +2 points). |
cancer |
Numeric (0 or 1). Active cancer. (1 = Yes, +1 point). |
creatinine_gt_1_2 |
Numeric (0 or 1). Abnormal creatinine levels (> 1.2 mg/dL). (1 = Yes, +1.5 points). |
hemoglobin_lt_13_or_12 |
Numeric (0 or 1). Anemia (Hemoglobin < 13 g/dL for men, < 12 g/dL for women). (1 = Yes, +1.5 points). |
pe_diagnosis |
Numeric (0 or 1). Clinically overt Pulmonary Embolism (PE). (1 = Yes, +1 point). |
A list containing:
RIETE_Score |
The calculated risk score (Range 0-8). |
Risk_Category |
Classification (Low: 0, Intermediate: 1-4, High: >4). |
Major_Bleeding_Risk_3_Months |
Estimated risk of major bleeding. |
Fatal_Bleeding_Risk_3_Months |
Estimated risk of fatal bleeding. |
Nieto JA, Solano R, Trapero-Gimeno I, et al. Fatal bleeding in patients receiving anticoagulant therapy for venous thromboembolism: findings from the RIETE registry. J Thromb Haemost. 2010;8(6):1216-1222. doi:10.1111/j.1538-7836.2010.03852.x
# Example 1: High Risk
# Recent Bleed (+2), Anemia (+1.5), Creatinine >1.2 (+1.5)
# Score = 5
riete_hemorrhage_risk(0, 1, 0, 1, 1, 0)
# Example 2: Low Risk
# 60yo, No risk factors
# Score = 0
riete_hemorrhage_risk(0, 0, 0, 0, 0, 0)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.