salivary_gland_cancer_port_survival: Salivary Gland Cancer Model for Survival +/- Postoperative...

View source: R/neelpackage.R

salivary_gland_cancer_port_survivalR Documentation

Salivary Gland Cancer Model for Survival +/- Postoperative Radiotherapy (PORT)

Description

Provides a structure to calculate overall survival probability for patients with resected major salivary gland cancer, with or without postoperative radiotherapy (PORT). This model is based on the study by Jacobs et al. using the National Cancer Database (NCDB). It helps in decision-making regarding the benefit of PORT by stratifying survival based on clinical and pathological factors.

Usage

salivary_gland_cancer_port_survival(age_at_diagnosis, sex, charlson_deyo_score,
                                    pathologic_t_stage, ratio_nodal_positivity,
                                    grade, surgical_margin, primary_site,
                                    port_received)

Arguments

age_at_diagnosis

Numeric. Patient age in years.

sex

String. "Male" or "Female".

charlson_deyo_score

Numeric. Charlson-Deyo comorbidity score (0, 1, 2, or >=3).

pathologic_t_stage

Numeric. AJCC Pathologic T Stage (1, 2, 3, or 4).

ratio_nodal_positivity

String. Ratio of positive lymph nodes to total nodes examined. Options: "0", "0.1-10", "10.1-49.9", ">=50".

grade

String. Tumor grade. Options: "low", "intermediate", "high".

surgical_margin

String. Status of surgical margins. Options: "negative", "positive".

primary_site

String. Primary tumor site. Options: "parotid", "submandibular", "sublingual".

port_received

String. Did the patient receive Postoperative Radiotherapy? "no", "yes".

Value

A list containing:

Note

Information regarding the calculation logic.

Inputs

The validated inputs provided for the model.

References

Jacobs CD, et al. Nomogram to Predict Survival Benefit of Postoperative Radiotherapy for Major Salivary Gland Cancers. Head Neck. 2020.

Examples

# Example: 65yo Male with T3N1 Parotid Cancer, Positive Margins
salivary_gland_cancer_port_survival(65, "male", 0, 3, "0.1-10", "high", "positive", "parotid", "no")

cliot documentation built on Dec. 1, 2025, 1:06 a.m.