| sofa_score | R Documentation |
Calculates the SOFA score to track a patient's status during their stay in an intensive care unit (ICU). The score determines the extent of a person's organ function or rate of failure. It is based on six different scores, one each for the respiratory, cardiovascular, hepatic, coagulation, renal, and neurological systems.
sofa_score(pao2, fio2, mechanical_ventilation, platelets, bilirubin,
mean_arterial_pressure, vasopressor_level, gcs, creatinine)
pao2 |
Numeric. Partial pressure of oxygen in arterial blood (mmHg). |
fio2 |
Numeric. Fraction of inspired oxygen (0.21 - 1.0 or 21 - 100). |
mechanical_ventilation |
Numeric (0 or 1). Is the patient on mechanical ventilation? (1 = Yes). |
platelets |
Numeric. Platelet count in x10^3/uL. |
bilirubin |
Numeric. Total bilirubin in mg/dL. |
mean_arterial_pressure |
Numeric. Mean Arterial Pressure in mmHg. |
vasopressor_level |
String. Level of vasopressor support. "none": No vasopressors. "low": Dopamine <= 5 or Dobutamine (any dose). "medium": Dopamine > 5, Epinephrine <= 0.1, or Norepinephrine <= 0.1. "high": Dopamine > 15, Epinephrine > 0.1, or Norepinephrine > 0.1. |
gcs |
Numeric. Glasgow Coma Scale score (3-15). |
creatinine |
Numeric. Serum creatinine in mg/dL. |
A list containing:
SOFA_Score |
The total calculated SOFA score (Range 0-24). |
Mortality_Estimate |
Approximate in-hospital mortality risk based on initial score. |
Organ_Scores |
A breakdown of scores for each organ system. |
Vincent JL, Moreno R, Takala J, et al. The SOFA (Sepsis-related Organ Failure Assessment) score to describe organ dysfunction/failure. On behalf of the Working Group on Sepsis-Related Problems of the European Society of Intensive Care Medicine. Intensive Care Med. 1996;22(7):707-710. doi:10.1007/bf01709751
sofa_score(80, 40, 1, 120, 1.5, 65, "medium", 13, 2.2)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.