| bap65_copd | R Documentation |
Calculates the BAP-65 score to stratify risk in patients presenting with an acute exacerbation of Chronic Obstructive Pulmonary Disease (COPD). The score correlates with in-hospital mortality and need for mechanical ventilation.
bap65_copd(bun, altered_mental_status, pulse, age)
bun |
Numeric. Blood Urea Nitrogen in mg/dL. (>= 25 mg/dL adds +1 point). |
altered_mental_status |
Numeric (0 or 1). Presence of altered mental status (GCS <= 14 or disorientation). (1 = Yes, +1 point). |
pulse |
Numeric. Heart rate in bpm. (>= 109 bpm adds +1 point). |
age |
Numeric. Patient age in years. (> 65 years adds +1 point). |
A list containing:
BAP65_Score |
The calculated score (Range 0-4). |
Risk_Class |
Classification (Class I to IV). |
In_Hospital_Mortality |
Estimated in-hospital mortality risk. |
Recommendation |
Clinical guidance regarding disposition (discharge, ward, or ICU). |
Shorr AF, Sun X, Johannes RS, Yaitanes A, Tabak YP. Validation of a novel risk score for severity of illness in acute exacerbations of COPD. Chest. 2011;140(5):1177-1183. doi:10.1378/chest.10-2851
# Example 1: High Risk (Class IV)
# BUN 30 (+1), Alert (0), Pulse 115 (+1), Age 70 (+1)
# Score = 3
bap65_copd(30, 0, 115, 70)
# Example 2: Low Risk (Class I)
# BUN 15 (0), Alert (0), Pulse 80 (0), Age 60 (0)
# Score = 0
bap65_copd(15, 0, 80, 60)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.